@@ -19,5 +19,4 @@ class UserSearch(AbstractUserSearch):
     pass
 
 
-# Import receiver functions
-from oscar.apps.analytics.receivers import *  # noqa
+from .receivers import *  # noqa
