@@ -115,18 +115,11 @@ class AbstractBasket(models.Model):
         if self.id is None:
             return self.lines.none()
         if self._lines is None:
-            self._lines = self.lines.select_related(
-                'product', 'product__stockrecord'
-            ).all().prefetch_related('attributes', 'product__images')
-
-            # Assign strategy to each line so it can use it to determine
-            # prices.  This is only needed for Django 1.4.5, where accessing
-            # self.basket from within the line will create a new basket
-            # instance (with no strategy assigned).  In later version, the
-            # original basket instance is cached and keeps its strategy
-            # property.
-            for line in self._lines:
-                line.strategy = self.strategy
+            self._lines = (
+                self.lines
+                .select_related('product', 'stockrecord')
+                .prefetch_related(
+                    'attributes', 'product__images'))
         return self._lines
 
     def is_quantity_allowed(self, qty):
@@ -329,7 +322,7 @@ class AbstractBasket(models.Model):
         base = '%s_%s' % (product.id, stockrecord.id)
         if not options:
             return base
-        return "%s_%s" % (base, zlib.crc32(str(options)))
+        return "%s_%s" % (base, zlib.crc32(repr(options).encode('utf8')))
 
     def _get_total(self, property):
         """
@@ -445,8 +438,7 @@ class AbstractBasket(models.Model):
     @property
     def num_items(self):
         """Return number of items"""
-        return reduce(
-            lambda num, line: num + line.quantity, self.lines.all(), 0)
+        return sum(line.quantity for line in self.lines.all())
 
     @property
     def num_items_without_discount(self):
@@ -599,18 +591,10 @@ class AbstractLine(models.Model):
                                  'quantity': self.quantity}
 
     def save(self, *args, **kwargs):
-        """
-        Saves a line or deletes if the quantity is 0
-        """
         if not self.basket.can_be_edited:
             raise PermissionDenied(
                 _("You cannot modify a %s basket") % (
                     self.basket.status.lower(),))
-        if self.quantity == 0:
-            # 'using' is the only kwarg that save() and delete() share
-            if 'using' in kwargs:
-                return self.delete(using=kwargs['using'])
-            return self.delete()
         return super(AbstractLine, self).save(*args, **kwargs)
 
     # =============
@@ -730,14 +714,12 @@ class AbstractLine(models.Model):
         if not hasattr(self, '_info'):
             # Cache the PurchaseInfo instance (note that a strategy instance is
             # assigned to each line by the basket in the all_lines method).
-            self._info = self.strategy.fetch_for_product(
+            self._info = self.basket.strategy.fetch_for_product(
                 self.product, self.stockrecord)
         return self._info
 
     @property
     def is_tax_known(self):
-        if not hasattr(self, 'strategy'):
-            return False
         return self.purchase_info.price.is_tax_known
 
     @property
