@@ -1,5 +1,5 @@
 from django import forms
-from django.db.models import get_model
+from oscar.core.loading import get_model
 from django.contrib.auth.forms import AuthenticationForm
 from django.utils.translation import ugettext_lazy as _
 
