@@ -8,15 +8,15 @@ from django.http import HttpResponseRedirect, Http404
 from django.contrib import messages
 from django.utils.translation import ugettext_lazy as _
 from django.contrib.auth import logout as auth_logout, login as auth_login
-from django.contrib.auth.forms import PasswordChangeForm
 from django.contrib.sites.models import get_current_site
 from django.conf import settings
-from django.db.models import get_model
+from oscar.core.loading import get_model
 
 from oscar.views.generic import PostActionMixin
 from oscar.apps.customer.utils import get_password_reset_url
 from oscar.core.loading import get_class, get_profile_class, get_classes
 from oscar.core.compat import get_user_model
+from . import signals
 
 PageTitleMixin, RegisterUserMixin = get_classes(
     'customer.mixins', ['PageTitleMixin', 'RegisterUserMixin'])
@@ -24,9 +24,10 @@ Dispatcher = get_class('customer.utils', 'Dispatcher')
 EmailAuthenticationForm, EmailUserCreationForm, OrderSearchForm = get_classes(
     'customer.forms', ['EmailAuthenticationForm', 'EmailUserCreationForm',
                        'OrderSearchForm'])
-ProfileForm = get_class('customer.forms', 'ProfileForm')
+PasswordChangeForm = get_class('customer.forms', 'PasswordChangeForm')
+ProfileForm, ConfirmPasswordForm = get_classes(
+    'customer.forms', ['ProfileForm', 'ConfirmPasswordForm'])
 UserAddressForm = get_class('address.forms', 'UserAddressForm')
-user_registered = get_class('customer.signals', 'user_registered')
 Order = get_model('order', 'Order')
 Line = get_model('basket', 'Line')
 Basket = get_model('basket', 'Basket')
@@ -163,7 +164,20 @@ class AccountAuthView(RegisterUserMixin, TemplateView):
     def validate_login_form(self):
         form = self.get_login_form(self.request)
         if form.is_valid():
+            user = form.get_user()
+
+            # Grab a reference to the session ID before logging in
+            old_session_key = self.request.session.session_key
+
             auth_login(self.request, form.get_user())
+
+            # Raise signal robustly (we don't want exceptions to crash the
+            # request handling). We use a custom signal as we want to track the
+            # session key before calling login (which cycles the session ID).
+            signals.user_logged_in.send_robust(
+                sender=self, request=self.request, user=user,
+                old_session_key=old_session_key)
+
             return HttpResponseRedirect(form.cleaned_data['redirect_url'])
 
         ctx = self.get_context_data(login_form=form)
@@ -180,7 +194,7 @@ class AccountAuthView(RegisterUserMixin, TemplateView):
 
 
 class LogoutView(RedirectView):
-    url = reverse_lazy('promotions:home')
+    url = settings.OSCAR_HOMEPAGE
     permanent = False
 
     def get(self, request, *args, **kwargs):
@@ -271,7 +285,8 @@ class ProfileUpdateView(PageTitleMixin, FormView):
 
         # We have to look up the email address from the form's
         # cleaned data because the object created by form.save() can
-        # either be a user or profile depending on AUTH_PROFILE_MODULE
+        # either be a user or profile instance depending whether a profile
+        # class has been specified by the AUTH_PROFILE_MODULE setting.
         new_email = form.cleaned_data['email']
         if old_user and new_email != old_user.email:
             # Email address has changed - send a confirmation email to the old
@@ -287,13 +302,33 @@ class ProfileUpdateView(PageTitleMixin, FormView):
                 code=self.communication_type_code, context=ctx)
             Dispatcher().dispatch_user_messages(old_user, msgs)
 
-        messages.success(self.request, "Profile updated")
+        messages.success(self.request, _("Profile updated"))
         return HttpResponseRedirect(self.get_success_url())
 
     def get_success_url(self):
         return reverse('customer:profile-view')
 
 
+class ProfileDeleteView(PageTitleMixin, FormView):
+    form_class = ConfirmPasswordForm
+    template_name = 'customer/profile/profile_delete.html'
+    page_title = _('Delete profile')
+    active_tab = 'profile'
+    success_url = settings.OSCAR_HOMEPAGE
+
+    def get_form_kwargs(self):
+        kwargs = super(ProfileDeleteView, self).get_form_kwargs()
+        kwargs['user'] = self.request.user
+        return kwargs
+
+    def form_valid(self, form):
+        self.request.user.delete()
+        messages.success(
+            self.request,
+            _("Your profile has now been deleted. Thanks for using the site."))
+        return HttpResponseRedirect(self.get_success_url())
+
+
 class ChangePasswordView(PageTitleMixin, FormView):
     form_class = PasswordChangeForm
     template_name = 'customer/profile/change_password_form.html'
@@ -347,7 +382,6 @@ class EmailDetailView(PageTitleMixin, DetailView):
     active_tab = 'emails'
 
     def get_object(self, queryset=None):
-        """Return an order object or 404"""
         return get_object_or_404(Email, user=self.request.user,
                                  id=self.kwargs['email_id'])
 
@@ -490,7 +524,6 @@ class OrderLineView(PostActionMixin, DetailView):
     """Customer order line"""
 
     def get_object(self, queryset=None):
-        """Return an order object or 404"""
         order = get_object_or_404(Order, user=self.request.user,
                                   number=self.kwargs['order_number'])
         return order.lines.get(id=self.kwargs['line_id'])
@@ -634,7 +667,15 @@ class AddressChangeStatusView(RedirectView):
     def get(self, request, pk=None, action=None, *args, **kwargs):
         address = get_object_or_404(UserAddress, user=self.request.user,
                                     pk=pk)
-        setattr(address, 'is_%s' % action, True)
+        #  We don't want the user to set an address as the default shipping
+        #  address, though they should be able to set it as their billing
+        #  address.
+        if address.country.is_shipping_country:
+            setattr(address, 'is_%s' % action, True)
+        elif action == 'default_for_billing':
+            setattr(address, 'is_default_for_billing', True)
+        else:
+            messages.error(request, _('We do not ship to this country'))
         address.save()
         return super(AddressChangeStatusView, self).get(
             request, *args, **kwargs)
