@@ -25,6 +25,11 @@ class CatalogueApplication(Application):
     product_createupdate_view = views.ProductCreateUpdateView
     product_delete_view = views.ProductDeleteView
 
+    product_class_create_view = views.ProductClassCreateView
+    product_class_list_view = views.ProductClassListView
+    product_class_update_view = views.ProductClassUpdateView
+    product_class_delete_view = views.ProductClassDeleteView
+
     category_list_view = views.CategoryListView
     category_detail_list_view = views.CategoryDetailListView
     category_create_view = views.CategoryCreateView
@@ -41,7 +46,7 @@ class CatalogueApplication(Application):
             url(r'^products/create/$',
                 self.product_create_redirect_view.as_view(),
                 name='catalogue-product-create'),
-            url(r'^products/create/(?P<product_class_id>\d+)/$',
+            url(r'^products/create/(?P<product_class_slug>[\w-]+)/$',
                 self.product_createupdate_view.as_view(),
                 name='catalogue-product-create'),
             url(r'^products/(?P<pk>\d+)/delete/$',
@@ -60,12 +65,28 @@ class CatalogueApplication(Application):
                 name='catalogue-category-detail-list'),
             url(r'^categories/create/$', self.category_create_view.as_view(),
                 name='catalogue-category-create'),
+            url(r'^categories/create/(?P<parent>\d+)$',
+                self.category_create_view.as_view(),
+                name='catalogue-category-create-child'),
             url(r'^categories/(?P<pk>\d+)/update/$',
                 self.category_update_view.as_view(),
                 name='catalogue-category-update'),
             url(r'^categories/(?P<pk>\d+)/delete/$',
                 self.category_delete_view.as_view(),
                 name='catalogue-category-delete'),
+            url(r'^product-type/create/$',
+                self.product_class_create_view.as_view(),
+                name='catalogue-class-create'),
+            url(r'^product-types/$',
+                self.product_class_list_view.as_view(),
+                name='catalogue-class-list'),
+            url(r'^product-type/(?P<pk>\d+)/update/$',
+                self.product_class_update_view.as_view(),
+                name='catalogue-class-update'),
+            url(r'^product-type/(?P<pk>\d+)/delete/$',
+                self.product_class_delete_view.as_view(),
+                name='catalogue-class-delete'),
+
         ]
         return self.post_process_urls(patterns('', *urls))
 
