@@ -30,3 +30,11 @@ class Price(object):
             self.tax = tax
         else:
             self.is_tax_known = False
+
+    def __repr__(self):
+        if self.is_tax_known:
+            return "%s(currency=%r, excl_tax=%r, incl_tax=%r, tax=%r)" % (
+                self.__class__.__name__, self.currency, self.excl_tax,
+                self.incl_tax, self.tax)
+        return "%s(currency=%r, excl_tax=%r)" % (
+            self.__class__.__name__, self.currency, self.excl_tax)
