@@ -1,3 +1,5 @@
+from __future__ import print_function
+from __future__ import print_function
 import logging
 import os
 import shutil
@@ -30,10 +32,10 @@ class Command(BaseCommand):
 
         source = os.path.realpath(
             os.path.join(os.path.dirname(__file__), '../../static'))
-        print "Copying Oscar's static files to %s" % (destination,)
+        print("Copying Oscar's static files to %s" % (destination,))
         shutil.copytree(source, destination)
 
         # Check if this new folder is in STATICFILES_DIRS
         if destination not in settings.STATICFILES_DIRS:
-            print ("You need to add %s to STATICFILES_DIRS in order for your "
-                   "local overrides to be picked up") % destination
+            print(("You need to add %s to STATICFILES_DIRS in order for your "
+                   "local overrides to be picked up") % destination)
