@@ -4,7 +4,7 @@ from optparse import make_option
 from django.core.management.base import BaseCommand, CommandError
 
 from oscar.core.loading import get_class
-CatalogueImporter = get_class('partner.utils', 'CatalogueImporter')
+CatalogueImporter = get_class('partner.importers', 'CatalogueImporter')
 CatalogueImportError = get_class('partner.exceptions', 'CatalogueImportError')
 
 logger = logging.getLogger('oscar.catalogue.import')
@@ -32,5 +32,5 @@ class Command(BaseCommand):
             logger.info(" - Importing records from '%s'" % file_path)
             try:
                 importer.handle(file_path)
-            except CatalogueImportError, e:
+            except CatalogueImportError as e:
                 raise CommandError(str(e))
