@@ -8,7 +8,7 @@ register = template.Library()
 
 
 @register.filter(name='currency')
-def currency(value):
+def currency(value, currency=None):
     """
     Format decimal value as currency
     """
@@ -17,11 +17,13 @@ def currency(value):
     except (TypeError, InvalidOperation):
         return u""
     # Using Babel's currency formatting
-    # http://packages.python.org/Babel/api/babel.numbers-module.html#format_currency
+    # http://babel.pocoo.org/docs/api/numbers/#babel.numbers.format_currency
     kwargs = {
-        'currency': settings.OSCAR_DEFAULT_CURRENCY,
-        'format': getattr(settings, 'OSCAR_CURRENCY_FORMAT', None)}
+        'currency': currency if currency else settings.OSCAR_DEFAULT_CURRENCY,
+        'format': getattr(settings, 'OSCAR_CURRENCY_FORMAT', None),
+    }
     locale = getattr(settings, 'OSCAR_CURRENCY_LOCALE', None)
     if locale:
         kwargs['locale'] = locale
+
     return format_currency(value, **kwargs)
